@@ -1,8 +1,9 @@
 from threading import local
 
+
 class Context(local):
     def __init__(self) -> None:
-        self._device: str = 'cuda:0'
+        self._device: str = "cuda:0"
         self._half_precision: bool = True
         self._vram_usage_level = None
 
@@ -12,7 +13,7 @@ class Context(local):
 
         self.device_name: str = None
         self.vram_optimizations: set = set()
-        '''
+        """
         **Do not change this unless you know what you're doing!** Instead set `context.vram_usage_level` to `'low'`, `'balanced'` or `'high'`.
 
         Possible values:
@@ -32,8 +33,8 @@ class Context(local):
         it consumes about 1 GB more than `'KEEP_ENTIRE_MODEL_IN_CPU'`, for a much faster rendering performance.
 
         * `'SET_ATTENTION_STEP_TO_16'`: Very useful! Lowest GPU memory utilization, but slowest performance.
-        '''
-        self.vram_usage_level = 'balanced'
+        """
+        self.vram_usage_level = "balanced"
 
     # hacky approach, but we need to enforce full precision for some devices
     # we also need to force full precision for these devices (haven't implemented this yet):
@@ -45,9 +46,10 @@ class Context(local):
     @device.setter
     def device(self, d):
         self._device = d
-        if d == 'cpu':
+        if d == "cpu":
             from sdkit.utils import log
-            log.info('forcing full precision for device: cpu')
+
+            log.info("forcing full precision for device: cpu")
             self._half_precision = False
 
     @property
@@ -56,7 +58,7 @@ class Context(local):
 
     @half_precision.setter
     def half_precision(self, h):
-        self._half_precision = h if self._device != 'cpu' else False
+        self._half_precision = h if self._device != "cpu" else False
 
     @property
     def vram_usage_level(self):
@@ -66,9 +68,9 @@ class Context(local):
     def vram_usage_level(self, level):
         self._vram_usage_level = level
 
-        if level == 'low':
-            self.vram_optimizations = {'KEEP_ENTIRE_MODEL_IN_CPU', 'SET_ATTENTION_STEP_TO_16'}
-        elif level == 'balanced':
-            self.vram_optimizations = {'KEEP_FS_AND_CS_IN_CPU', 'SET_ATTENTION_STEP_TO_16'}
-        elif level == 'high':
-            self.vram_optimizations = {'SET_ATTENTION_STEP_TO_2'}
+        if level == "low":
+            self.vram_optimizations = {"KEEP_ENTIRE_MODEL_IN_CPU", "SET_ATTENTION_STEP_TO_16"}
+        elif level == "balanced":
+            self.vram_optimizations = {"KEEP_FS_AND_CS_IN_CPU", "SET_ATTENTION_STEP_TO_16"}
+        elif level == "high":
+            self.vram_optimizations = {"SET_ATTENTION_STEP_TO_2"}
